@@ -1,7 +1,6 @@
 package Text::Xslate::Compiler;
-use warnings FATAL => 'recursion';
-use Any::Moose;
-use Any::Moose '::Util::TypeConstraints';
+use Mouse;
+use Mouse::Util::TypeConstraints;
 
 use Scalar::Util ();
 use Carp         ();
@@ -209,7 +208,7 @@ sub _build_parser {
         return $syntax;
     }
     else {
-        my $parser_class = Any::Moose::load_first_existing_class(
+        my $parser_class = Mouse::Util::load_first_existing_class(
             "Text::Xslate::Syntax::" . $syntax,
             $syntax,
         );
@@ -1123,11 +1122,12 @@ sub _generate_unary {
 
     my $id = $node->id;
     if(exists $unary{$id}) {
+        my @operand = $self->compile_ast($node->first);
         my @code = (
-            $self->compile_ast($node->first),
+            @operand,
             $self->opcode( $unary{$id} )
         );
-        if( $OPTIMIZE and $self->_code_is_literal($code[0]) ) {
+        if( $OPTIMIZE and $self->_code_is_literal(@operand) ) {
             $self->_fold_constants(\@code);
         }
         return @code;
@@ -1418,7 +1418,9 @@ sub can_be_in_list_context {
 
 sub _code_is_literal {
     my($self, @code) = @_;
-    return @code == 1 && $code[0][_OP_NAME] eq 'literal';
+    return @code == 1
+        && (    $code[0][_OP_NAME] eq 'literal'
+             || $code[0][_OP_NAME] eq 'literal_i');
 }
 
 sub _fold_constants {
@@ -1592,8 +1594,8 @@ sub _error {
     die $self->make_error($message, $self->file, $line);
 }
 
-no Any::Moose;
-no Any::Moose '::Util::TypeConstraints';
+no Mouse;
+no Mouse::Util::TypeConstraints;
 
 __PACKAGE__->meta->make_immutable;
 __END__
